# Visualization

::: fdtdx.core.plotting.device_permittivity_index_utils.index_matrix_to_str
::: fdtdx.core.plotting.device_permittivity_index_utils.device_matrix_index_figure
::: fdtdx.core.plotting.utils.plot_filled_std_curves
::: fdtdx.core.plotting.debug.generate_unique_filename
::: fdtdx.core.plotting.debug.debug_plot_2d
::: fdtdx.core.plotting.colors
